@@ -41,6 +41,7 @@ pub enum Token<'input> {
     Event,
     Error,
     Enum,
+    Type,
 
     Memory,
     Storage,
@@ -73,6 +74,8 @@ pub enum Token<'input> {
     Uint(u16),
     Int(u16),
     Bytes(u8),
+    // prior to 0.8.0 `byte` used to be an alias for `bytes1`
+    Byte,
     DynamicBytes,
     Bool,
     Address,
@@ -206,6 +209,7 @@ impl<'input> fmt::Display for Token<'input> {
             Token::Uint(w) => write!(f, "uint{}", w),
             Token::Int(w) => write!(f, "int{}", w),
             Token::Bytes(w) => write!(f, "bytes{}", w),
+            Token::Byte => write!(f, "byte"),
             Token::DynamicBytes => write!(f, "bytes"),
             Token::Semicolon => write!(f, ";"),
             Token::Comma => write!(f, ","),
@@ -266,6 +270,7 @@ impl<'input> fmt::Display for Token<'input> {
             Token::Event => write!(f, "event"),
             Token::Error => write!(f, "error"),
             Token::Enum => write!(f, "enum"),
+            Token::Type => write!(f, "type"),
             Token::Memory => write!(f, "memory"),
             Token::Storage => write!(f, "storage"),
             Token::Calldata => write!(f, "calldata"),
@@ -434,7 +439,7 @@ static KEYWORDS: phf::Map<&'static str, Token> = phf_map! {
     "bytes31" => Token::Bytes(31),
     "bytes32" => Token::Bytes(32),
     "bytes" => Token::DynamicBytes,
-    "byte" => Token::Bytes(1),
+    "byte" => Token::Byte,
     "calldata" => Token::Calldata,
     "case" => Token::Case,
     "constant" => Token::Constant,
@@ -510,6 +515,7 @@ static KEYWORDS: phf::Map<&'static str, Token> = phf_map! {
     "switch" => Token::Switch,
     "throw" => Token::Throw,
     "true" => Token::True,
+    "type" => Token::Type,
     "uint8" => Token::Uint(8),
     "uint16" => Token::Uint(16),
     "uint24" => Token::Uint(24),
