@@ -116,10 +116,10 @@ pub struct SingleDocComment {
     pub value: String,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct SourceUnit(pub Vec<SourceUnitPart>);
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub enum SourceUnitPart {
     ContractDefinition(Box<ContractDefinition>),
     PragmaDirective(Loc, Vec<DocComment>, Identifier, StringLiteral),
@@ -130,10 +130,11 @@ pub enum SourceUnitPart {
     ErrorDefinition(Box<ErrorDefinition>),
     FunctionDefinition(Box<FunctionDefinition>),
     VariableDefinition(Box<VariableDefinition>),
+    TypeDefinition(Box<TypeDefinition>),
     StraySemicolon(Loc),
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub enum Import {
     Plain(StringLiteral, Loc),
     GlobalSymbol(StringLiteral, Identifier, Loc),
@@ -196,7 +197,7 @@ pub struct VariableDeclaration {
     pub name: Identifier,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 #[allow(clippy::vec_box)]
 pub struct StructDefinition {
     pub doc: Vec<DocComment>,
@@ -205,7 +206,7 @@ pub struct StructDefinition {
     pub fields: Vec<VariableDeclaration>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub enum ContractPart {
     StructDefinition(Box<StructDefinition>),
     EventDefinition(Box<EventDefinition>),
@@ -213,11 +214,12 @@ pub enum ContractPart {
     ErrorDefinition(Box<ErrorDefinition>),
     VariableDefinition(Box<VariableDefinition>),
     FunctionDefinition(Box<FunctionDefinition>),
+    TypeDefinition(Box<TypeDefinition>),
     StraySemicolon(Loc),
     Using(Box<Using>),
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct Using {
     pub loc: Loc,
     pub library: Identifier,
@@ -250,7 +252,7 @@ pub struct Base {
     pub args: Option<Vec<Expression>>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct ContractDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
@@ -260,7 +262,7 @@ pub struct ContractDefinition {
     pub parts: Vec<ContractPart>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct EventParameter {
     pub ty: Expression,
     pub loc: Loc,
@@ -268,7 +270,7 @@ pub struct EventParameter {
     pub name: Option<Identifier>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct EventDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
@@ -277,14 +279,14 @@ pub struct EventDefinition {
     pub anonymous: bool,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct ErrorParameter {
     pub ty: Expression,
     pub loc: Loc,
     pub name: Option<Identifier>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct ErrorDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
@@ -292,7 +294,7 @@ pub struct ErrorDefinition {
     pub fields: Vec<ErrorParameter>,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct EnumDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
@@ -308,7 +310,7 @@ pub enum VariableAttribute {
     Override(Loc),
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct VariableDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
@@ -318,6 +320,14 @@ pub struct VariableDefinition {
     pub initializer: Option<Expression>,
 }
 
+#[derive(Debug, PartialEq, Clone)]
+pub struct TypeDefinition {
+    pub doc: Vec<DocComment>,
+    pub loc: Loc,
+    pub name: Identifier,
+    pub ty: Expression,
+}
+
 #[derive(Debug, PartialEq, Clone)]
 pub struct StringLiteral {
     pub loc: Loc,
@@ -583,7 +593,7 @@ impl fmt::Display for FunctionTy {
     }
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone)]
 pub struct FunctionDefinition {
     pub doc: Vec<DocComment>,
     pub loc: Loc,
